from typing import List

from monkeytypes import InfectionMonkeyBaseModel, NetworkPort
from pydantic import Field


class HadoopOptions(InfectionMonkeyBaseModel):
    target_ports: List[NetworkPort] = Field(
        default=[8088],
        title="Target Ports",
        description="A list of HTTP ports that the Hadoop exploiter will try to exploit.",
    )
    try_all_discovered_http_ports: bool = Field(
        default=False,
        title="Try All Discovered HTTP Ports",
        description="Attempt to exploit Hadoop on all HTTP ports discovered from network scanning.",
    )
    request_timeout: float = Field(
        gt=0.0,
        default=15.0,
        title="HTTP Request Timeout",
        description="The maximum time (in seconds) to wait for a response from a Hadoop server.",
    )
    agent_binary_download_timeout: float = Field(
        gt=0.0,
        default=60.0,
        title="Agent Binary Download Timeout",
        description="The maximum time (in seconds) to wait for a successfully exploited"
        " Hadoop server to download the agent binary.",
    )
    yarn_application_suffix: str = Field(
        default="M0NK3Y3XPL01T",
        title="YARN Application Name Suffix",
        description="A string that will be appended to a unique YARN application name.",
    )
